export declare enum SessionState {
    Created = "Created",
    Recording = "Recording",
    Paused = "Paused",
    Ended = "Ended",
    EndConfirmed = "EndConfirmed",
    Uploaded = "Uploaded",
    UploadConfirmed = "UploadConfirmed"
}
export declare enum StorageService {
    none = "upload"
}
export declare enum RecordingOrigin {
    Screen = "Screen",
    Mic = "Mic",
    Camera = "Camera"
}
export declare enum AlertCategory {
    LostFocus = 25,
    PotentialCamera = 32,
    SpyDeviceDisconnected = 33
}
export declare enum AlertType {
    Audio = 1,
    Video = 2,
    Screen = 3,
    Image = 4,
    Environment = 5
}
export interface Alert {
    begin: number;
    end: number;
    alert: AlertCategory;
    type: AlertType;
}
export interface Recording {
    origin: RecordingOrigin;
    file: File;
    device: string;
    upload?: {
        storage: StorageService;
        azureUrl: string;
        awsUrl: string;
    };
}
export declare class ProctoringSession {
    id: string;
    state: SessionState;
    startedAt: Date;
    sessionDuration: number;
    alerts: Alert[];
    recordings: Recording[];
    get hasSomethingToUpload(): boolean;
    constructor();
    start(): void;
    pause(): void;
    resume(): void;
    stop(): void;
    setProctoringId(proctoringId: string): void;
    setEndConfirmed(): void;
    setUploaded(): void;
    setUploadConfirmed(): void;
    addAlert(alert: Alert): void;
    addRecording(rec: Recording): void;
}
